/*
FORM_CHANGE_ITEM_HOLD:
    Form change activates when the specified item is given to or taken from the selected Pokémon.
    Alternatively, form change activates when the specified item is is given to or taken from
    the selected Pokémon that has a particular ability.
    param1 = item to hold
    param2 = ability to check for, optional

FORM_CHANGE_ITEM_USE:
    Form change activates when the item is used on the selected Pokémon.
    param1 = item to use
    param2 = DAY if form change activates in the daytime, optional
             NIGHT if form change activates at nighttime, optional

FORM_CHANGE_MOVE:
    Form change activates when the Pokémon learns or forgets the move.
    param1 = move to check for
    param2 = WHEN_LEARNED if form change activates when move is forgotten
             WHEN_FORGOTTEN if form change activates when move is learned

FORM_CHANGE_WITHDRAW:
    Form change activates when the Pokémon is withdrawn from the PC or Daycare.
    No parameters.

FORM_CHANGE_FAINT:
    Form change activates when the Pokémon faints, either in battle or in the overworld by poison.
    If species is not specified and it's on the player's side, it will try to use the value
    saved in gBattleStruct->changedSpecies from a previous form change.
    No parameters.

FORM_CHANGE_BATTLE_BEGIN:
    Form change activates when the Pokémon is sent out at the beginning of a battle
    param1 = item to hold, optional
    param2 = a move that will be replaced, optional
    param3 = a new move to replace it with, optional

FORM_CHANGE_BATTLE_END:
    Form change activates at the end of a battle. If species is not specified and it's on the player's side,
    it will try to use the value saved in gBattleStruct->changedSpecies from a previous form change.
    param1 = item to hold, optional
    param2 = a move that will be replaced, optional
    param3 = a new move to replace it with, optional

FORM_CHANGE_BATTLE_SWITCH:
    Form change activates when the Pokémon is switched out in battle.
    No parameters.

FORM_CHANGE_BATTLE_HP_PERCENT:
    Form change activates when the Pokémon's HP % passes a certain threshold.
    param1 = Ability to check.
    param2 = HP_HIGHER_THAN if the form triggers when the current HP is higher than the specified threshold.
             HP_LOWER_EQ_THAN if the form triggers when the current HP is lower or equal than the specified threshold.
    param3 = HP percentage threshold.

FORM_CHANGE_MEGA_EVOLUTION_ITEM:
    Form change activates when the mon has the defined item. If it's on the player's side, it also requires
    ITEM_MEGA_RING in the user's bag and for the player to choose to enable it.
    param1 = item to hold.

FORM_CHANGE_MEGA_EVOLUTION_MOVE:
    Form change activates when the mon has the defined move. If it's on the player's side, it also requires
    ITEM_MEGA_RING in the user's bag and for the player to choose to enable it.
    param1 = move to have.

FORM_CHANGE_PRIMAL_REVERSION:
    Form change activates automatically when entering battle with the specified item. If the item is a Red Orb,
    it uses the Omega Symbol for the animation and icon. Otherwise, it defaults to Alpha.
    param1 = item to hold.
*/

// FORM_CHANGE_MOVE param2 Arguments
#define WHEN_LEARNED    0
#define WHEN_FORGOTTEN  1

// FORM_CHANGE_ITEM_USE param2 Arguments
#define DAY    1
#define NIGHT  2

static const struct FormChange sVenusaurFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_VENUSAUR_MEGA, ITEM_VENUSAURITE},
    {FORM_CHANGE_FAINT,                 SPECIES_VENUSAUR},
    {FORM_CHANGE_BATTLE_END,            SPECIES_VENUSAUR},
    {FORM_CHANGE_END},
};

static const struct FormChange sCharizardFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_CHARIZARD_MEGA_X, ITEM_CHARIZARDITE_X},
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_CHARIZARD_MEGA_Y, ITEM_CHARIZARDITE_Y},
    {FORM_CHANGE_FAINT,                 SPECIES_CHARIZARD},
    {FORM_CHANGE_BATTLE_END,            SPECIES_CHARIZARD},
    {FORM_CHANGE_END},
};

static const struct FormChange sBlastoiseFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_BLASTOISE_MEGA, ITEM_BLASTOISINITE},
    {FORM_CHANGE_FAINT,                 SPECIES_BLASTOISE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_BLASTOISE},
    {FORM_CHANGE_END},
};

static const struct FormChange sBeedrillFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_BEEDRILL_MEGA, ITEM_BEEDRILLITE},
    {FORM_CHANGE_FAINT,                 SPECIES_BEEDRILL},
    {FORM_CHANGE_BATTLE_END,            SPECIES_BEEDRILL},
    {FORM_CHANGE_END},
};

static const struct FormChange sPidgeotFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_PIDGEOT_MEGA, ITEM_PIDGEOTITE},
    {FORM_CHANGE_FAINT,                 SPECIES_PIDGEOT},
    {FORM_CHANGE_BATTLE_END,            SPECIES_PIDGEOT},
    {FORM_CHANGE_END},
};

static const struct FormChange sAlakazamFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_ALAKAZAM_MEGA, ITEM_ALAKAZITE},
    {FORM_CHANGE_FAINT,                 SPECIES_ALAKAZAM},
    {FORM_CHANGE_BATTLE_END,            SPECIES_ALAKAZAM},
    {FORM_CHANGE_END},
};

static const struct FormChange sSlowbroFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_SLOWBRO_MEGA, ITEM_SLOWBRONITE},
    {FORM_CHANGE_FAINT,                 SPECIES_SLOWBRO},
    {FORM_CHANGE_BATTLE_END,            SPECIES_SLOWBRO},
    {FORM_CHANGE_END},
};

static const struct FormChange sGengarFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_GENGAR_MEGA, ITEM_GENGARITE},
    {FORM_CHANGE_FAINT,                 SPECIES_GENGAR},
    {FORM_CHANGE_BATTLE_END,            SPECIES_GENGAR},
    {FORM_CHANGE_END},
};

static const struct FormChange sKangaskhanFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_KANGASKHAN_MEGA, ITEM_KANGASKHANITE},
    {FORM_CHANGE_FAINT,                 SPECIES_KANGASKHAN},
    {FORM_CHANGE_BATTLE_END,            SPECIES_KANGASKHAN},
    {FORM_CHANGE_END},
};

static const struct FormChange sPinsirFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_PINSIR_MEGA, ITEM_PINSIRITE},
    {FORM_CHANGE_FAINT,                 SPECIES_PINSIR},
    {FORM_CHANGE_BATTLE_END,            SPECIES_PINSIR},
    {FORM_CHANGE_END},
};

static const struct FormChange sGyaradosFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_GYARADOS_MEGA, ITEM_GYARADOSITE},
    {FORM_CHANGE_FAINT,                 SPECIES_GYARADOS},
    {FORM_CHANGE_BATTLE_END,            SPECIES_GYARADOS},
    {FORM_CHANGE_END},
};

static const struct FormChange sAerodactylFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_AERODACTYL_MEGA, ITEM_AERODACTYLITE},
    {FORM_CHANGE_FAINT,                 SPECIES_AERODACTYL},
    {FORM_CHANGE_BATTLE_END,            SPECIES_AERODACTYL},
    {FORM_CHANGE_END},
};

static const struct FormChange sMewtwoFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_MEWTWO_MEGA_X, ITEM_MEWTWONITE_X},
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_MEWTWO_MEGA_Y, ITEM_MEWTWONITE_Y},
    {FORM_CHANGE_FAINT,                 SPECIES_MEWTWO},
    {FORM_CHANGE_BATTLE_END,            SPECIES_MEWTWO},
    {FORM_CHANGE_END},
};

static const struct FormChange sAmpharosFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_AMPHAROS_MEGA, ITEM_AMPHAROSITE},
    {FORM_CHANGE_FAINT,                 SPECIES_AMPHAROS},
    {FORM_CHANGE_BATTLE_END,            SPECIES_AMPHAROS},
    {FORM_CHANGE_END},
};

static const struct FormChange sSteelixFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_STEELIX_MEGA, ITEM_STEELIXITE},
    {FORM_CHANGE_FAINT,                 SPECIES_STEELIX},
    {FORM_CHANGE_BATTLE_END,            SPECIES_STEELIX},
    {FORM_CHANGE_END},
};

static const struct FormChange sScizorFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_SCIZOR_MEGA, ITEM_SCIZORITE},
    {FORM_CHANGE_FAINT,                 SPECIES_SCIZOR},
    {FORM_CHANGE_BATTLE_END,            SPECIES_SCIZOR},
    {FORM_CHANGE_END},
};

static const struct FormChange sHeracrossFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_HERACROSS_MEGA, ITEM_HERACRONITE},
    {FORM_CHANGE_FAINT,                 SPECIES_HERACROSS},
    {FORM_CHANGE_BATTLE_END,            SPECIES_HERACROSS},
    {FORM_CHANGE_END},
};

static const struct FormChange sHoundoomFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_HOUNDOOM_MEGA, ITEM_HOUNDOOMINITE},
    {FORM_CHANGE_FAINT,                 SPECIES_HOUNDOOM},
    {FORM_CHANGE_BATTLE_END,            SPECIES_HOUNDOOM},
    {FORM_CHANGE_END},
};

static const struct FormChange sTyranitarFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_TYRANITAR_MEGA, ITEM_TYRANITARITE},
    {FORM_CHANGE_FAINT,                 SPECIES_TYRANITAR},
    {FORM_CHANGE_BATTLE_END,            SPECIES_TYRANITAR},
    {FORM_CHANGE_END},
};

static const struct FormChange sSceptileFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_SCEPTILE_MEGA, ITEM_SCEPTILITE},
    {FORM_CHANGE_FAINT,                 SPECIES_SCEPTILE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_SCEPTILE},
    {FORM_CHANGE_END},
};

static const struct FormChange sBlazikenFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_BLAZIKEN_MEGA, ITEM_BLAZIKENITE},
    {FORM_CHANGE_FAINT,                 SPECIES_BLAZIKEN},
    {FORM_CHANGE_BATTLE_END,            SPECIES_BLAZIKEN},
    {FORM_CHANGE_END},
};

static const struct FormChange sSwampertFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_SWAMPERT_MEGA, ITEM_SWAMPERTITE},
    {FORM_CHANGE_FAINT,                 SPECIES_SWAMPERT},
    {FORM_CHANGE_BATTLE_END,            SPECIES_SWAMPERT},
    {FORM_CHANGE_END},
};

static const struct FormChange sSableyeFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_SABLEYE_MEGA, ITEM_SABLENITE},
    {FORM_CHANGE_FAINT,                 SPECIES_SABLEYE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_SABLEYE},
    {FORM_CHANGE_END},
};

static const struct FormChange sSharpedoFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_SHARPEDO_MEGA, ITEM_SHARPEDONITE},
    {FORM_CHANGE_FAINT,                 SPECIES_SHARPEDO},
    {FORM_CHANGE_BATTLE_END,            SPECIES_SHARPEDO},
    {FORM_CHANGE_END},
};

static const struct FormChange sManectricFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_MANECTRIC_MEGA, ITEM_MANECTITE},
    {FORM_CHANGE_FAINT,                 SPECIES_MANECTRIC},
    {FORM_CHANGE_BATTLE_END,            SPECIES_MANECTRIC},
    {FORM_CHANGE_END},
};

static const struct FormChange sCameruptFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_CAMERUPT_MEGA, ITEM_CAMERUPTITE},
    {FORM_CHANGE_FAINT,                 SPECIES_CAMERUPT},
    {FORM_CHANGE_BATTLE_END,            SPECIES_CAMERUPT},
    {FORM_CHANGE_END},
};

static const struct FormChange sGlalieFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_GLALIE_MEGA, ITEM_GLALITITE},
    {FORM_CHANGE_FAINT,                 SPECIES_GLALIE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_GLALIE},
    {FORM_CHANGE_END},
};

static const struct FormChange sMawileFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_MAWILE_MEGA, ITEM_MAWILITE},
    {FORM_CHANGE_FAINT,                 SPECIES_MAWILE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_MAWILE},
    {FORM_CHANGE_END},
};

static const struct FormChange sMedichamFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_MEDICHAM_MEGA, ITEM_MEDICHAMITE},
    {FORM_CHANGE_FAINT,                 SPECIES_MEDICHAM},
    {FORM_CHANGE_BATTLE_END,            SPECIES_MEDICHAM},
    {FORM_CHANGE_END},
};

static const struct FormChange sAltariaFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_ALTARIA_MEGA, ITEM_ALTARIANITE},
    {FORM_CHANGE_FAINT,                 SPECIES_ALTARIA},
    {FORM_CHANGE_BATTLE_END,            SPECIES_ALTARIA},
    {FORM_CHANGE_END},
};

static const struct FormChange sAbsolFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_ABSOL_MEGA, ITEM_ABSOLITE},
    {FORM_CHANGE_FAINT,                 SPECIES_ABSOL},
    {FORM_CHANGE_BATTLE_END,            SPECIES_ABSOL},
    {FORM_CHANGE_END},
};

static const struct FormChange sBanetteFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_BANETTE_MEGA, ITEM_BANETTITE},
    {FORM_CHANGE_FAINT,                 SPECIES_BANETTE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_BANETTE},
    {FORM_CHANGE_END},
};

static const struct FormChange sAggronFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_AGGRON_MEGA, ITEM_AGGRONITE},
    {FORM_CHANGE_FAINT,                 SPECIES_AGGRON},
    {FORM_CHANGE_BATTLE_END,            SPECIES_AGGRON},
    {FORM_CHANGE_END},
};

static const struct FormChange sGardevoirFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_GARDEVOIR_MEGA, ITEM_GARDEVOIRITE},
    {FORM_CHANGE_FAINT,                 SPECIES_GARDEVOIR},
    {FORM_CHANGE_BATTLE_END,            SPECIES_GARDEVOIR},
    {FORM_CHANGE_END},
};

static const struct FormChange sSalamenceFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_SALAMENCE_MEGA, ITEM_SALAMENCITE},
    {FORM_CHANGE_FAINT,                 SPECIES_SALAMENCE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_SALAMENCE},
    {FORM_CHANGE_END},
};

static const struct FormChange sMetagrossFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_METAGROSS_MEGA, ITEM_METAGROSSITE},
    {FORM_CHANGE_FAINT,                 SPECIES_METAGROSS},
    {FORM_CHANGE_BATTLE_END,            SPECIES_METAGROSS},
    {FORM_CHANGE_END},
};

static const struct FormChange sLatiasFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_LATIAS_MEGA, ITEM_LATIASITE},
    {FORM_CHANGE_FAINT,                 SPECIES_LATIAS},
    {FORM_CHANGE_BATTLE_END,            SPECIES_LATIAS},
    {FORM_CHANGE_END},
};

static const struct FormChange sLatiosFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_LATIOS_MEGA, ITEM_LATIOSITE},
    {FORM_CHANGE_FAINT,                 SPECIES_LATIOS},
    {FORM_CHANGE_BATTLE_END,            SPECIES_LATIOS},
    {FORM_CHANGE_END},
};

static const struct FormChange sKyogreFormChangeTable[] = {
    {FORM_CHANGE_PRIMAL_REVERSION,  SPECIES_KYOGRE_PRIMAL, ITEM_BLUE_ORB},
    {FORM_CHANGE_BATTLE_END,        SPECIES_KYOGRE},
    {FORM_CHANGE_END},
};

static const struct FormChange sGroudonFormChangeTable[] = {
    {FORM_CHANGE_PRIMAL_REVERSION,  SPECIES_GROUDON_PRIMAL, ITEM_RED_ORB},
    {FORM_CHANGE_BATTLE_END,        SPECIES_GROUDON},
    {FORM_CHANGE_END},
};

static const struct FormChange sRayquazaFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_MOVE,   SPECIES_RAYQUAZA_MEGA, MOVE_DRAGON_ASCENT},
    {FORM_CHANGE_FAINT,                 SPECIES_RAYQUAZA},
    {FORM_CHANGE_BATTLE_END,            SPECIES_RAYQUAZA},
    {FORM_CHANGE_END},
};

#if P_GEN_4_POKEMON == TRUE
static const struct FormChange sLopunnyFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_LOPUNNY_MEGA, ITEM_LOPUNNITE},
    {FORM_CHANGE_FAINT,                 SPECIES_LOPUNNY},
    {FORM_CHANGE_BATTLE_END,            SPECIES_LOPUNNY},
    {FORM_CHANGE_END},
};

static const struct FormChange sGarchompFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_GARCHOMP_MEGA, ITEM_GARCHOMPITE},
    {FORM_CHANGE_FAINT,                 SPECIES_GARCHOMP},
    {FORM_CHANGE_BATTLE_END,            SPECIES_GARCHOMP},
    {FORM_CHANGE_END},
};

static const struct FormChange sLucarioFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_LUCARIO_MEGA, ITEM_LUCARIONITE},
    {FORM_CHANGE_FAINT,                 SPECIES_LUCARIO},
    {FORM_CHANGE_BATTLE_END,            SPECIES_LUCARIO},
    {FORM_CHANGE_END},
};

static const struct FormChange sAbomasnowFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_ABOMASNOW_MEGA, ITEM_ABOMASITE},
    {FORM_CHANGE_FAINT,                 SPECIES_ABOMASNOW},
    {FORM_CHANGE_BATTLE_END,            SPECIES_ABOMASNOW},
    {FORM_CHANGE_END},
};

static const struct FormChange sGalladeFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_GALLADE_MEGA, ITEM_GALLADITE},
    {FORM_CHANGE_FAINT,                 SPECIES_GALLADE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_GALLADE},
    {FORM_CHANGE_END},
};

static const struct FormChange sGiratinaFormChangeTable[] = {
    {FORM_CHANGE_ITEM_HOLD, SPECIES_GIRATINA, ITEM_NONE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_GIRATINA_ORIGIN, ITEM_GRISEOUS_ORB},
    {FORM_CHANGE_END},
};

static const struct FormChange sShayminFormChangeTable[] = {
    {FORM_CHANGE_ITEM_USE, SPECIES_SHAYMIN_SKY, ITEM_GRACIDEA, DAY},
    // {FORM_CHANGE_WITHDRAW, SPECIES_SHAYMIN},
    {FORM_CHANGE_END},
};

static const struct FormChange sArceusFormChangeTable[] = {
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS,          ITEM_NONE,         ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_FIGHTING, ITEM_FIST_PLATE,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_FIGHTING, ITEM_FIGHTINIUM_Z, ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_FLYING,   ITEM_SKY_PLATE,    ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_FLYING,   ITEM_FLYINIUM_Z,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_POISON,   ITEM_TOXIC_PLATE,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_POISON,   ITEM_POISONIUM_Z,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_ROCK,     ITEM_STONE_PLATE,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_ROCK,     ITEM_ROCKIUM_Z,    ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_GROUND,   ITEM_EARTH_PLATE,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_GROUND,   ITEM_GROUNDIUM_Z,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_BUG,      ITEM_INSECT_PLATE, ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_BUG,      ITEM_BUGINIUM_Z,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_GHOST,    ITEM_SPOOKY_PLATE, ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_GHOST,    ITEM_GHOSTIUM_Z,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_STEEL,    ITEM_IRON_PLATE,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_STEEL,    ITEM_STEELIUM_Z,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_FIRE,     ITEM_FLAME_PLATE,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_FIRE,     ITEM_FIRIUM_Z,     ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_WATER,    ITEM_SPLASH_PLATE, ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_WATER,    ITEM_WATERIUM_Z,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_GRASS,    ITEM_MEADOW_PLATE, ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_GRASS,    ITEM_GRASSIUM_Z,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_ELECTRIC, ITEM_ZAP_PLATE,    ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_ELECTRIC, ITEM_ELECTRIUM_Z,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_PSYCHIC,  ITEM_MIND_PLATE,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_PSYCHIC,  ITEM_PSYCHIUM_Z,   ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_ICE,      ITEM_ICICLE_PLATE, ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_ICE,      ITEM_ICIUM_Z,      ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_DRAGON,   ITEM_DRACO_PLATE,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_DRAGON,   ITEM_DRAGONIUM_Z,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_DARK,     ITEM_DREAD_PLATE,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_DARK,     ITEM_DARKINIUM_Z,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_FAIRY,    ITEM_PIXIE_PLATE,  ABILITY_MULTITYPE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_ARCEUS_FAIRY,    ITEM_FAIRIUM_Z,    ABILITY_MULTITYPE},
    {FORM_CHANGE_END},
};
#endif

#if P_GEN_5_POKEMON == TRUE
static const struct FormChange sAudinoFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_AUDINO_MEGA, ITEM_AUDINITE},
    {FORM_CHANGE_FAINT,                 SPECIES_AUDINO},
    {FORM_CHANGE_BATTLE_END,            SPECIES_AUDINO},
    {FORM_CHANGE_END},
};

static const struct FormChange sDarmanitanFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_DARMANITAN,          ABILITY_ZEN_MODE, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_DARMANITAN_ZEN_MODE, ABILITY_ZEN_MODE, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_FAINT,             SPECIES_DARMANITAN},
    {FORM_CHANGE_BATTLE_END,        SPECIES_DARMANITAN},
    {FORM_CHANGE_END},
};

static const struct FormChange sDarmanitanGalarianFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_DARMANITAN_GALARIAN,          ABILITY_ZEN_MODE, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_DARMANITAN_ZEN_MODE_GALARIAN, ABILITY_ZEN_MODE, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_FAINT,             SPECIES_DARMANITAN_GALARIAN},
    {FORM_CHANGE_BATTLE_END,        SPECIES_DARMANITAN_GALARIAN},
    {FORM_CHANGE_END},
};

static const struct FormChange sMeloettaFormChangeTable[] = {
    {FORM_CHANGE_FAINT,         SPECIES_MELOETTA},
    {FORM_CHANGE_BATTLE_END,    SPECIES_MELOETTA},
    {FORM_CHANGE_END},
};

static const struct FormChange sTornadusFormChangeTable[] = {
    {FORM_CHANGE_ITEM_USE, SPECIES_TORNADUS_THERIAN, ITEM_REVEAL_GLASS},
    {FORM_CHANGE_ITEM_USE, SPECIES_TORNADUS, ITEM_REVEAL_GLASS},
    {FORM_CHANGE_END},
};

static const struct FormChange sThundurusFormChangeTable[] = {
    {FORM_CHANGE_ITEM_USE, SPECIES_THUNDURUS_THERIAN, ITEM_REVEAL_GLASS},
    {FORM_CHANGE_ITEM_USE, SPECIES_THUNDURUS, ITEM_REVEAL_GLASS},
    {FORM_CHANGE_END},
};

static const struct FormChange sLandorusFormChangeTable[] = {
    {FORM_CHANGE_ITEM_USE, SPECIES_LANDORUS_THERIAN, ITEM_REVEAL_GLASS},
    {FORM_CHANGE_ITEM_USE, SPECIES_LANDORUS, ITEM_REVEAL_GLASS},
    {FORM_CHANGE_END},
};

static const struct FormChange sKeldeoFormChangeTable[] = {
    // {FORM_CHANGE_MOVE, SPECIES_KELDEO_RESOLUTE, MOVE_SECRET_SWORD, WHEN_LEARNED},
    // {FORM_CHANGE_MOVE, SPECIES_KELDEO, MOVE_SECRET_SWORD, WHEN_FORGOTTEN},
    {FORM_CHANGE_END},
};

static const struct FormChange sGenesectFormChangeTable[] = {
    {FORM_CHANGE_ITEM_HOLD, SPECIES_GENESECT,             ITEM_NONE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_GENESECT_DOUSE_DRIVE, ITEM_DOUSE_DRIVE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_GENESECT_SHOCK_DRIVE, ITEM_SHOCK_DRIVE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_GENESECT_BURN_DRIVE,  ITEM_BURN_DRIVE},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_GENESECT_CHILL_DRIVE, ITEM_CHILL_DRIVE},
    {FORM_CHANGE_END},
};
#endif

#if P_GEN_6_POKEMON == TRUE
static const struct FormChange sGreninjaBattleBondFormChangeTable[] = {
    {FORM_CHANGE_FAINT,         SPECIES_GRENINJA_BATTLE_BOND},
    {FORM_CHANGE_BATTLE_END,    SPECIES_GRENINJA_BATTLE_BOND},
    {FORM_CHANGE_END},
};

static const struct FormChange sAegislashFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_SWITCH, SPECIES_AEGISLASH},
    {FORM_CHANGE_FAINT,         SPECIES_AEGISLASH},
    {FORM_CHANGE_BATTLE_END,    SPECIES_AEGISLASH},
    {FORM_CHANGE_END},
};

static const struct FormChange sXerneasFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_BEGIN, SPECIES_XERNEAS_ACTIVE},
    {FORM_CHANGE_BATTLE_END,   SPECIES_XERNEAS,      },
    {FORM_CHANGE_END},
};

static const struct FormChange sZygardePowerConstructFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_ZYGARDE_COMPLETE, ABILITY_POWER_CONSTRUCT, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_FAINT},
    {FORM_CHANGE_BATTLE_END},
    {FORM_CHANGE_END},
};

static const struct FormChange sDiancieFormChangeTable[] = {
    {FORM_CHANGE_MEGA_EVOLUTION_ITEM,   SPECIES_DIANCIE_MEGA, ITEM_DIANCITE},
    {FORM_CHANGE_FAINT,                 SPECIES_DIANCIE},
    {FORM_CHANGE_BATTLE_END,            SPECIES_DIANCIE},
    {FORM_CHANGE_END},
};

static const struct FormChange sHoopaFormChangeTable[] = {
    {FORM_CHANGE_ITEM_USE, SPECIES_HOOPA_UNBOUND, ITEM_PRISON_BOTTLE, SPECIES_HOOPA},
    {FORM_CHANGE_WITHDRAW, SPECIES_HOOPA},
    {FORM_CHANGE_END},
};
#endif

#if P_GEN_7_POKEMON == TRUE
static const struct FormChange sOricorioFormChangeTable[] = {
    {FORM_CHANGE_ITEM_USE, SPECIES_ORICORIO,         ITEM_RED_NECTAR},
    {FORM_CHANGE_ITEM_USE, SPECIES_ORICORIO_POM_POM, ITEM_YELLOW_NECTAR},
    {FORM_CHANGE_ITEM_USE, SPECIES_ORICORIO_PAU,     ITEM_PINK_NECTAR},
    {FORM_CHANGE_ITEM_USE, SPECIES_ORICORIO_SENSU,   ITEM_PURPLE_NECTAR},
    {FORM_CHANGE_END},
};
static const struct FormChange sWishiwashiFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_WISHIWASHI_SCHOOL, ABILITY_SCHOOLING, HP_HIGHER_THAN,   25},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_WISHIWASHI,        ABILITY_SCHOOLING, HP_LOWER_EQ_THAN, 25},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_WISHIWASHI},
    {FORM_CHANGE_FAINT,             SPECIES_WISHIWASHI},
    {FORM_CHANGE_BATTLE_END,        SPECIES_WISHIWASHI},
    {FORM_CHANGE_END},
};

static const struct FormChange sSilvallyFormChangeTable[] = {
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY,          ITEM_NONE,            ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_FIGHTING, ITEM_FIGHTING_MEMORY, ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_FLYING,   ITEM_FLYING_MEMORY,   ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_POISON,   ITEM_POISON_MEMORY,   ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_GROUND,   ITEM_GROUND_MEMORY,   ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_ROCK,     ITEM_ROCK_MEMORY,     ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_BUG,      ITEM_BUG_MEMORY,      ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_GHOST,    ITEM_GHOST_MEMORY,    ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_STEEL,    ITEM_STEEL_MEMORY,    ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_FIRE,     ITEM_FIRE_MEMORY,     ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_WATER,    ITEM_WATER_MEMORY,    ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_GRASS,    ITEM_GRASS_MEMORY,    ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_ELECTRIC, ITEM_ELECTRIC_MEMORY, ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_PSYCHIC,  ITEM_PSYCHIC_MEMORY,  ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_ICE,      ITEM_ICE_MEMORY,      ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_DRAGON,   ITEM_DRAGON_MEMORY,   ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_DARK,     ITEM_DARK_MEMORY,     ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_ITEM_HOLD, SPECIES_SILVALLY_FAIRY,    ITEM_FAIRY_MEMORY,    ABILITY_RKS_SYSTEM},
    {FORM_CHANGE_END},
};

static const struct FormChange sMimikyuFormChangeTable[] = {
    {FORM_CHANGE_FAINT,         SPECIES_MIMIKYU},
    {FORM_CHANGE_BATTLE_END,    SPECIES_MIMIKYU},
    {FORM_CHANGE_END},
};

static const struct FormChange sMiniorRedFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR,          ABILITY_SHIELDS_DOWN, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_CORE_RED, ABILITY_SHIELDS_DOWN, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_MINIOR_CORE_RED},
    {FORM_CHANGE_FAINT,             SPECIES_MINIOR_CORE_RED},
    {FORM_CHANGE_BATTLE_END,        SPECIES_MINIOR_CORE_RED},
    {FORM_CHANGE_END},
};
static const struct FormChange sMiniorBlueFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_METEOR_BLUE, ABILITY_SHIELDS_DOWN, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_CORE_BLUE,   ABILITY_SHIELDS_DOWN, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_MINIOR_CORE_BLUE},
    {FORM_CHANGE_FAINT,             SPECIES_MINIOR_CORE_BLUE},
    {FORM_CHANGE_BATTLE_END,        SPECIES_MINIOR_CORE_BLUE},
    {FORM_CHANGE_END},
};
static const struct FormChange sMiniorGreenFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_METEOR_GREEN, ABILITY_SHIELDS_DOWN, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_CORE_GREEN,   ABILITY_SHIELDS_DOWN, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_MINIOR_CORE_GREEN},
    {FORM_CHANGE_FAINT,             SPECIES_MINIOR_CORE_GREEN},
    {FORM_CHANGE_BATTLE_END,        SPECIES_MINIOR_CORE_GREEN},
    {FORM_CHANGE_END},
};
static const struct FormChange sMiniorIndigoFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_METEOR_INDIGO, ABILITY_SHIELDS_DOWN, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_CORE_INDIGO,   ABILITY_SHIELDS_DOWN, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_MINIOR_CORE_INDIGO},
    {FORM_CHANGE_FAINT,             SPECIES_MINIOR_CORE_INDIGO},
    {FORM_CHANGE_BATTLE_END,        SPECIES_MINIOR_CORE_INDIGO},
    {FORM_CHANGE_END},
};
static const struct FormChange sMiniorOrangeFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_METEOR_ORANGE, ABILITY_SHIELDS_DOWN, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_CORE_ORANGE,   ABILITY_SHIELDS_DOWN, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_MINIOR_CORE_ORANGE},
    {FORM_CHANGE_FAINT,             SPECIES_MINIOR_CORE_ORANGE},
    {FORM_CHANGE_BATTLE_END,        SPECIES_MINIOR_CORE_ORANGE},
    {FORM_CHANGE_END},
};
static const struct FormChange sMiniorVioletFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_METEOR_VIOLET, ABILITY_SHIELDS_DOWN, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_CORE_VIOLET,   ABILITY_SHIELDS_DOWN, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_MINIOR_CORE_VIOLET},
    {FORM_CHANGE_FAINT,             SPECIES_MINIOR_CORE_VIOLET},
    {FORM_CHANGE_BATTLE_END,        SPECIES_MINIOR_CORE_VIOLET},
    {FORM_CHANGE_END},
};
static const struct FormChange sMiniorYellowFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_METEOR_YELLOW, ABILITY_SHIELDS_DOWN, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_MINIOR_CORE_YELLOW,   ABILITY_SHIELDS_DOWN, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_MINIOR_CORE_YELLOW},
    {FORM_CHANGE_FAINT,             SPECIES_MINIOR_CORE_YELLOW},
    {FORM_CHANGE_BATTLE_END,        SPECIES_MINIOR_CORE_YELLOW},
    {FORM_CHANGE_END},
};
#endif

#if P_GEN_8_POKEMON == TRUE
static const struct FormChange sCramorantFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_CRAMORANT_GULPING, ABILITY_GULP_MISSILE, HP_HIGHER_THAN,   50},
    {FORM_CHANGE_BATTLE_HP_PERCENT, SPECIES_CRAMORANT_GORGING, ABILITY_GULP_MISSILE, HP_LOWER_EQ_THAN, 50},
    {FORM_CHANGE_BATTLE_SWITCH,     SPECIES_CRAMORANT},
    {FORM_CHANGE_FAINT,             SPECIES_CRAMORANT},
    {FORM_CHANGE_BATTLE_END,        SPECIES_CRAMORANT},
    {FORM_CHANGE_END},
};

static const struct FormChange sMorpekoFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_SWITCH, SPECIES_MORPEKO},
    {FORM_CHANGE_FAINT,         SPECIES_MORPEKO},
    {FORM_CHANGE_BATTLE_END,    SPECIES_MORPEKO},
    {FORM_CHANGE_END},
};

static const struct FormChange sZacianFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_BEGIN, SPECIES_ZACIAN_CROWNED_SWORD, ITEM_RUSTED_SWORD, MOVE_IRON_HEAD,      MOVE_BEHEMOTH_BLADE},
    {FORM_CHANGE_BATTLE_END,   SPECIES_ZACIAN,               ITEM_RUSTED_SWORD, MOVE_BEHEMOTH_BLADE, MOVE_IRON_HEAD},
    {FORM_CHANGE_END},
};

static const struct FormChange sZamazentaFormChangeTable[] = {
    {FORM_CHANGE_BATTLE_BEGIN, SPECIES_ZAMAZENTA_CROWNED_SHIELD, ITEM_RUSTED_SHIELD, MOVE_IRON_HEAD,      MOVE_BEHEMOTH_BASH},
    {FORM_CHANGE_BATTLE_END,   SPECIES_ZAMAZENTA,                ITEM_RUSTED_SHIELD, MOVE_BEHEMOTH_BASH,  MOVE_IRON_HEAD},
    {FORM_CHANGE_END},
};

static const struct FormChange sEnamorusFormChangeTable[] = {
    {FORM_CHANGE_ITEM_USE, SPECIES_ENAMORUS, ITEM_REVEAL_GLASS},
    {FORM_CHANGE_ITEM_USE, SPECIES_ENAMORUS_THERIAN, ITEM_REVEAL_GLASS},
    {FORM_CHANGE_END},
};
#endif

#undef WHEN_LEARNED
#undef WHEN_FORGOTTEN
